@@ -5,9 +5,9 @@
 PyTypeObject ResSummaryMiscType;
 
 static PyStructSequence_Field ResSummaryMiscType_fields[] = {
-    {"iDummy", ""},
-    {"fDummy", ""},
-    {"cDummy", ""},
+    {"iDummy", "Integer misc data"},
+    {"fDummy", "Float misc data"},
+    {"cDummy", "String misc data"},
     {
         NULL,
     },
@@ -45,7 +45,7 @@ PyObject *create_ResSummaryMisc(ResSummaryMiscStruct *misc_struct)
     PyObject *cDummy_obj = PyTuple_New(10);
     for (int i = 0; i < 10; i++)
     {
-        const size_t str_len = trim(misc_struct->cDummy[i], MAX_ID_LEN);
+        const Py_ssize_t str_len = trim(misc_struct->cDummy[i], MAX_ID_LEN);
         PyTuple_SET_ITEM(cDummy_obj, i,
                          Py_BuildValue("s#", misc_struct->cDummy[i], str_len));
     }
